@@ -1,14 +1,19 @@
 import peewee
 from peewee import Model, EXCLUDED
 
+from airflow import AirflowException
+
 
 class BaseModel(Model):
     def bulk_save(self, rows: list, transaction_count=None):
         conflict_fields = self.get_model_indexes()
         update_fields = self.get_excluded_fields()
 
+        # Delete duplicates
+        rows = list({''.join([str(x.get(field)) for field in conflict_fields]): x for x in rows}.values())
+
         if not rows:
-            return
+            raise AirflowExecption("rows are empty")
 
         if not transaction_count:
             transaction_count = len(rows)
@@ -79,9 +84,20 @@ class BaseModel(Model):
         return schema
 
     def get_model_indexes(self):
-        indexes = list(self._meta.indexes)
+        # Init vars
+        indexes = []
 
-        return indexes[0][0] if indexes else []
+        # Get model primary key if exist
+        _primary_key_field = getattr(getattr(self._meta, 'primary_key'), 'name', None)
+
+        if self._meta.indexes:
+            if self._meta.indexes[0]:
+                indexes = list(self._meta.indexes[0][0])
+
+        if not indexes:
+            indexes = [_primary_key_field]
+
+        return tuple(indexes)
 
     def get_model_fields(self):
         fields = self._meta.fields
